@@ -30,7 +30,7 @@ AcordTraverse::AcordTraverse(Acord2* acord2)
 {
   try
     {
-      for (PointID p : AC.missingXY_)
+      for (PointID p : AC.missing_xy_)
         // if (!PD[p].test_xy()) ... AC.missingXY_ cannot have xy
         {
           std::set<PointID> t = get_neighbours(p);
@@ -46,14 +46,17 @@ AcordTraverse::AcordTraverse(Acord2* acord2)
 
 void AcordTraverse::execute() //to keep in line with the acord class
 {
+  auto etalon_candidate_points = candidate_traverse_points_;
   std::set<PointID>::iterator it = candidate_traverse_points_.begin();
   while (candidate_traverse_points_.size() > 1 && it != candidate_traverse_points_.end())
     {
+	  traverse_points_.clear();
+	  traverse.clear();
       // If there is one then add pt to traverse_pts and remove from candidates,
       traverse_points_.push_back(*it);
       get_traverse_pts(*it);   // populating the traverse_points_
 
-      if (traverse_points_.size() > 1)
+      if (traverse_points_.size() > 2)
         {
           tr_type = get_connecting_points();
           //if there are at least two points in traverse_pts then I can calculate the polygon and insert into traverses
@@ -61,48 +64,52 @@ void AcordTraverse::execute() //to keep in line with the acord class
           if (success)
             { 
               AC.traverses.push_back({ traverse, tr_type });
+
+			  for (auto t : traverse_points_)
+				  {
+				    candidate_traverse_points_.erase(t);
+				  }
+			  it = candidate_traverse_points_.begin();
             }
           else
             {
               // Computation failed
+			  for (auto t : traverse_points_)
+				  {
+				  auto found = std::find(etalon_candidate_points.begin(), etalon_candidate_points.end(), t);
+				  if(found != etalon_candidate_points.end()) candidate_traverse_points_.insert(t);
+				  }
+			  ++it;
             }
 
-          for (auto t : traverse_points_)
-            {
-              candidate_traverse_points_.erase(t);
-            }
-          it = candidate_traverse_points_.begin();
-          traverse_points_.clear();
-          traverse.clear();
         }
       else
         {
           for (auto t : traverse_points_)
             {
-              candidate_traverse_points_.insert(t);
+			  auto found = std::find(etalon_candidate_points.begin(), etalon_candidate_points.end(), t);
+			  if (found != etalon_candidate_points.end()) candidate_traverse_points_.insert(t);
             }
-          traverse_points_.clear();
-          traverse.clear();
-          ++it;
+		  ++it;
         }
-
     }
 
   // now we have all traverses we can try to find same points
   std::set<PointID> added_points = add_same_points();
   if (!added_points.empty())
     {
-      auto cnt_before = AC.missingXY_.size();
+      auto cnt_before = AC.missing_xy_.size();
       AC.get_medians();
-      auto cnt_after = AC.missingXY_.size();
+      auto cnt_after = AC.missing_xy_.size();
       if (cnt_before != cnt_after)
         {
-          /* check which traverses contain the points that are now known and edit
-           * them and their traverse type
+          /* check which traverses contain the points that are now
+           * known and edit them and their traverse type
            */
           for (auto tr : AC.traverses)
             {
-              // if it's a closed traverse we already know coords of both points and we can add them
+              // if it's a closed traverse we already know coords of
+              // both points and we can add them
               if (tr.second == AC.closed_traverse) continue;
               PointID tr_pointid = tr.first.back().id;
 
@@ -114,7 +121,8 @@ void AcordTraverse::execute() //to keep in line with the acord class
                   tr.first.back().coords = PD[tr_pointid]; //set the newly computed coords
                   tr.second = AC.closed_traverse;
 
-                  // now we can add computed points to PD and remove them from missingXY
+                  // now we can add computed points to PD and remove
+                  // them from missingXY
                   if (AC.transform_traverse(tr.first))
                     {
                       for (auto pt : tr.first)
@@ -123,8 +131,8 @@ void AcordTraverse::execute() //to keep in line with the acord class
                             {
                               // only setting the coords, leaving other info as is
                               PD[pt.id].set_xy(pt.coords.x(), pt.coords.y());
-                              AC.missingXY_.erase(pt.id);
-                              AC.new_points_++;
+                              AC.missing_xy_.erase(pt.id);
+                              AC.new_points_xy_++;
                             }
                         }
                     }
@@ -136,7 +144,15 @@ void AcordTraverse::execute() //to keep in line with the acord class
   // now we just iterate through the traverses one more time and if the
   // last point is known, we can safely remove them from the list
   
-  AC.traverses.erase(std::remove_if(AC.traverses.begin(), AC.traverses.end(), [this](std::pair<Acord2::Traverse, Acord2::Traverse_type> tr) {return (!AC.in_missingXY(tr.first.back().id)); }), AC.traverses.end());
+  if(!AC.traverses.empty())
+    {
+	  AC.traverses.erase(std::remove_if(
+		  AC.traverses.begin(), 
+		  AC.traverses.end(), 
+	    [this](std::pair<Acord2::Traverse, Acord2::Traverse_type> tr) {
+		  return (!AC.in_missingXY(tr.first.back().id));
+		  }), AC.traverses.end());
+	}
 
 }
 
@@ -152,12 +168,12 @@ std::set<PointID> AcordTraverse::add_same_points()
 	bool found = false;
 	  for (auto pt : (*itr).first)
 		{
-		  auto fit = AC.same_points_.find (pt.id);
+		  auto fit = AC.same_points_xy_.find (pt.id);
 		  auto ait = added_points.find (pt.id);
 
-		  if (fit != AC.same_points_.end() && ait == added_points.end())
+		  if (fit != AC.same_points_xy_.end() && ait == added_points.end())
 			{
-			  AC.same_points_.insert({pt.id, pt.coords});
+			  AC.same_points_xy_.insert({pt.id, pt.coords});
 			  found = true;
 			}
 		}
@@ -174,8 +190,8 @@ std::set<PointID> AcordTraverse::add_same_points()
               if (AC.in_missingXY(pt.id))
                 {
                   PD[pt.id].set_xy(pt.coords.x(), pt.coords.y());
-                  AC.missingXY_.erase(pt.id);
-                  AC.new_points_++;
+                  AC.missing_xy_.erase(pt.id);
+                  AC.new_points_xy_++;
                 }
             }
         }
@@ -192,11 +208,11 @@ std::set<PointID> AcordTraverse::add_same_points()
             {
               if (!found_already)
                 {
-                  AC.same_points_.insert({ comp_point.id, comp_point.coords });
+                  AC.same_points_xy_.insert({ comp_point.id, comp_point.coords });
                   found_already = true;
                   added_points.insert(comp_point.id);
                 }
-              AC.same_points_.insert({ (*initr).first.back().id, (*initr).first.back().coords });
+              AC.same_points_xy_.insert({ (*initr).first.back().id, (*initr).first.back().coords });
             }
         }
 
@@ -344,7 +360,7 @@ bool AcordTraverse::calculate_traverse()
                 {
                   if (i == 0 && !AC.in_missingXY(it->second->to()) && !front_ori.second)
                     {
-                      StandPoint* sp = AC.find_standpoint(it->second->from());
+					  StandPoint* sp = AC.find_standpoint(it->second->from());
                       if (sp != nullptr)
                         {
                           if (!sp->test_orientation())
@@ -409,7 +425,7 @@ bool AcordTraverse::calculate_traverse()
                 }
               else if ((known_dirs == 00 || known_dirs == 10))
                 {
-                  if (i == 0 && !AC.in_missingXY(itt->second->to()) && !front_ori.second)
+                  if (i == 0 && !AC.in_missingXY(itt->second->from()) && !front_ori.second)
                     {
                       StandPoint* sp = AC.find_standpoint(itt->second->from());
                       if (sp != nullptr)
@@ -424,7 +440,7 @@ bool AcordTraverse::calculate_traverse()
                             }
                           if (sp->test_orientation())
                             {
-                              traverse.push_back({ itt->second->to(),PD[itt->second->to()] });
+                              traverse.push_back({ itt->second->from(),PD[itt->second->from()] });
                               known_dirs += 1;
                               double dirval = M_PI - dir.first;
                               angle_from_dirs += (dirval + sp->orientation());
@@ -456,6 +472,17 @@ bool AcordTraverse::calculate_traverse()
             }
           ++itt;
         }
+	  if(tmp_bearings.empty() && known_dirs == 10 && i==0 && tr_type == AC.closed_traverse)
+		{
+		  front_ori = { 0, true };
+		  while (angle_from_dirs > 2 * M_PI)
+			  angle_from_dirs -= 2 * M_PI;
+		  while (angle_from_dirs < 0)
+			  angle_from_dirs += 2 * M_PI;
+		  tmp_bearings.push_back(angle_from_dirs);
+		  angle_from_dirs = 0;
+		  known_dirs = 0;
+	    }
       if (!tmp_dists.empty() &&!tmp_bearings.empty())
         {
           distances.push_back(AC.median(tmp_dists));
@@ -474,13 +501,19 @@ bool AcordTraverse::calculate_traverse()
               traverse_points_.pop_back();
               i = -1;
             }
+		  else if(i==0)
+			{
+			  //the point is in the first place, but type is not closed
+			  //there is no other choice but to go back
+			  return false;
+			}
           else
             {
               //if the point is in the middle we can try
               //to end the traverse here and compute the
               //stuff we have got
               tr_type = AC.closed_start_traverse;
-              for (auto t = traverse_points_.size()-1; t<i-1; --t)
+              for (auto t = traverse_points_.size()-1; t>i; --t)
                 {
                   candidate_traverse_points_.insert(traverse_points_[t]);
                   traverse_points_.pop_back();
@@ -535,7 +568,7 @@ bool AcordTraverse::calculate_traverse()
     }
 
   //look for second orientation
-  if (tr_type == AC.closed_traverse && !AC.in_missingXY(traverse_points_.back()))
+  if ((tr_type == AC.closed_traverse || tr_type == AC.closed_start_traverse))
     {
       std::set<PointID> neighbours = get_neighbours(traverse_points_.back());
       std::pair<double, bool> ori_back = { 0, false };
@@ -545,6 +578,7 @@ bool AcordTraverse::calculate_traverse()
             {
               traverse.push_back({n, PD[n]});
               ori_back.second = true;
+			     tr_type = AC.closed_traverse;
             }
         }
     }
