@@ -1,24 +1,23 @@
 /*
-    Geodesy and Mapping C++ library (GNU GaMa)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
-                  2011  Vaclav Petras <wenzeslaus@gmail.com>
-                  2013  Ales Cepek <cepek@gnu.org>
+  Geodesy and Mapping C++ library (GNU GaMa)
+  Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+                2011  Vaclav Petras <wenzeslaus@gmail.com>
+                2013, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library.
+  This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /** \file adjusted_observations.h
@@ -52,7 +51,7 @@ private:
     GNU_gama::local::LocalNetwork* IS;
     const int maxval;
     const GNU_gama::local::Vec& v; ///< residuals
-    GNU_gama::Index i;
+    int i;
     const int y_sign;
 
     static const int distPrecision = 5;
@@ -77,14 +76,14 @@ public:
     {}
 
     /** \brief Sets index of observation which will be used in the next visit. */
-    void setObservationIndex(GNU_gama::Index index) { i = index; }
+    void setObservationIndex(int index) { i = index; }
 
     void visit(Distance* obs)
     {
         out << T_GaMa_distance;
         out.precision(distPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -96,7 +95,7 @@ public:
         out << T_GaMa_direction;
         out.precision(angularPrecision);
         out.width(maxval);
-        Double m = R2G*(obs->value());
+        double m = R2G*(obs->value());
         if (IS->gons())
             out << m << " ";
         else
@@ -119,7 +118,7 @@ public:
         out << T_GaMa_angle;
         out.precision(angularPrecision);
         out.width(maxval);
-        Double m = R2G*(obs->value());
+        double m = R2G*(obs->value());
         if (IS->gons())
             out << m << " ";
         else
@@ -139,7 +138,7 @@ public:
         out << T_GaMa_levell;
         out.precision(distPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -151,7 +150,7 @@ public:
         out << T_GaMa_s_distance;
         out.precision(distPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -163,7 +162,7 @@ public:
         out << T_GaMa_z_angle;
         out.precision(angularPrecision);
         out.width(maxval);
-        Double m = R2G*(obs->value());
+        double m = R2G*(obs->value());
         if (IS->gons())
             out << m << " ";
         else
@@ -180,7 +179,7 @@ public:
         out << T_GaMa_x;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -191,7 +190,7 @@ public:
         out << T_GaMa_y;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << y_sign*m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -203,7 +202,7 @@ public:
         out << T_GaMa_z;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -214,7 +213,7 @@ public:
         out << T_GaMa_xdiff;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -226,7 +225,7 @@ public:
         out << T_GaMa_ydiff;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << y_sign*m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -238,7 +237,7 @@ public:
         out << T_GaMa_zdiff;
         out.precision(coordPrecision);
         out.width(maxval);
-        Double m = obs->value();
+        double m = obs->value();
         out << m << " ";
         out.width(maxval);
         m += v(i)/1000;
@@ -250,7 +249,7 @@ public:
         out << T_GaMa_azimuth;
         out.precision(angularPrecision);
         out.width(maxval);
-        Double m = R2G*(obs->value());
+        double m = R2G*(obs->value());
         if (IS->gons())
             out << m << " ";
         else
@@ -272,7 +271,6 @@ void AdjustedObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 {
    using namespace std;
    using namespace GNU_gama::local;
-   // using GNU_gama::local::Double;
 
    const int    y_sign = IS->y_sign();
    const Vec&   v      = IS->residuals();
@@ -305,7 +303,7 @@ void AdjustedObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
        }
    }
 
-   Double kki = IS->conf_int_coef();
+   double kki = IS->conf_int_coef();
    out.width(IS->maxw_obs());
    out << "i" << " ";
    out.width(IS->maxw_id());
@@ -354,7 +352,7 @@ void AdjustedObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
       out.precision(1);
       out.width(7);
-      Double ml = IS->stdev_obs(i);
+      double ml = IS->stdev_obs(i);
       if (dynamic_cast<Direction*>(pm))
         ml *= scale;
       else if (dynamic_cast<Angle*>(pm))
