@@ -1,26 +1,25 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / matvec)
-    Copyright (C) 2002, 2005, 2007  Ales Cepek <cepek@gnu.org>
+  C++ Matrix/Vector templates (GNU Gama / matvec)
+  Copyright (C) 2002, 2005, 2007, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ Matrix/Vector template library.
+  This file is part of the GNU Gama C++ Matrix/Vector template library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef GNU_gama_CovMat_gMatVec_Symmetric_Band_Matrix_2_H_
-#define GNU_gama_CovMat_gMatVec_Symmetric_Band_Matrix_2_H_
+#ifndef GNU_gama_CovMat_gMatVec_Symmetric_Band_Matrix_2_h
+#define GNU_gama_CovMat_gMatVec_Symmetric_Band_Matrix_2_h
 
 #include <matvec/matvec.h>
 #include <matvec/choldec.h>
@@ -44,16 +43,19 @@
 namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
 
 
-  template <typename Float=double, typename Exc=Exception::matvec>
-  class CovMat : public MatBase<Float, Exc>, public CholDecLD<Float, Exc> {
+  template <typename Float=double,
+            typename Index=int,
+            typename Exc=Exception::matvec>
+  class CovMat : public MatBase<Float, Index, Exc>,
+                 public CholDecLD<Float, Index, Exc> {
   public:
 
     CovMat() : band_(0), band_1(0), dim_b(0)
     {
     }
     CovMat(Index d, Index b)
-      : MatBase<Float, Exc>(d,d,d*(b+1) - b*(b+1)/2), band_(b),
-        band_1(b+1), dim_b(d-b)
+      : MatBase<Float, Index, Exc>(d,d,d*(b+1) - b*(b+1)/2), band_(b),
+      band_1(b+1), dim_b(d-b)
     {
     }
 
@@ -69,14 +71,14 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
     Float  operator ()(Index, Index) const;
     Float& operator ()(Index, Index);
     void   cholDec  ();
-    void   solve    (Vec<Float, Exc>&) const;
+    void   solve    (Vec<Float, Index, Exc>&) const;
 
     const Float* operator[](Index row) const
     {
       const Float* a_ = this->begin() + --row*band_1;
       if (row > dim_b) {
-	const Index i_  = row - dim_b;
-	a_ -= i_*(i_+1)/2;
+        const Index i_  = row - dim_b;
+        a_ -= i_*(i_+1)/2;
       }
       return a_;
     }
@@ -92,7 +94,7 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
       return a_;
     }
 
-    Vec<Float, Exc> operator*(const Vec<Float, Exc>&) const;
+    Vec<Float, Index, Exc> operator*(const Vec<Float, Index, Exc>&) const;
 
     std::istream&  read (std::istream&);
     std::ostream&  write(std::ostream&) const;
@@ -104,9 +106,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   };      /* class CovMat */
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   void
-  CovMat<Float, Exc>::reset(Index d, Index b)
+  CovMat<Float, Index, Exc>::reset(Index d, Index b)
   {
     if (dim() != d || band_ != b)
       {
@@ -119,9 +121,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   Float
-  CovMat<Float, Exc>::operator()(Index r, Index s) const
+  CovMat<Float, Index, Exc>::operator()(Index r, Index s) const
   {
     if (r > s) {
       Index t = r;
@@ -137,9 +139,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   Float&
-  CovMat<Float, Exc>::operator()(Index r, Index s)
+  CovMat<Float, Index, Exc>::operator()(Index r, Index s)
   {
     if (r > s) {
       Index t = r;
@@ -156,9 +158,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   void
-  CovMat<Float, Exc>::cholDec()
+  CovMat<Float, Index, Exc>::cholDec()
   {
     /*
      * Cholesky factorization of positive definite matrix A = L*D*trans(L)
@@ -193,7 +195,7 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
         for (n=1; n<=k; n++)
           {
             q = B[n]/pivot;
-	    for (l=n; l<=k; l++) p[l] -= q*B[l];
+            for (l=n; l<=k; l++) p[l] -= q*B[l];
             p += min(W, N-row-n);
           }
 
@@ -203,9 +205,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   void
-  CovMat<Float, Exc>::solve(Vec<Float, Exc>& rhs) const
+  CovMat<Float, Index, Exc>::solve(Vec<Float, Index, Exc>& rhs) const
   {
     using namespace std;
     Index i, j, k;
@@ -234,11 +236,11 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
-  Vec<Float, Exc>
-  CovMat<Float, Exc>::operator*(const Vec<Float, Exc>& v) const
+  template <typename Float, typename Index, typename Exc>
+  Vec<Float, Index, Exc>
+  CovMat<Float, Index, Exc>::operator*(const Vec<Float, Index, Exc>& v) const
   {
-    Vec<Float, Exc> T(dim());
+    Vec<Float, Index, Exc> T(dim());
     Index i, j, k;
     Float s;
 
@@ -260,9 +262,9 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   std::istream&
-  CovMat<Float, Exc>::read(std::istream& inp)
+  CovMat<Float, Index, Exc>::read(std::istream& inp)
   {
     int inpd, inpb;
     inp >> inpd >> inpb;
@@ -278,11 +280,11 @@ namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
   }
 
 
-  template <typename Float, typename Exc>
+  template <typename Float, typename Index, typename Exc>
   std::ostream&
-  CovMat<Float, Exc>::write(std::ostream& out) const
+  CovMat<Float, Index, Exc>::write(std::ostream& out) const
   {
-    int w = out.width();
+    auto w = out.width();
     out.width(w);
     out << dim() << ' ';
     out.width(w);
